# Contributing Guide

Please, for now, only contribute in the form of:

- [Bug reports](https://github.com/hynek/svcs/issues),
- [suggestions](https://github.com/hynek/svcs/discussions/categories/ideas).
- and [feedback](https://github.com/hynek/svcs/discussions/1)

The project is still too much in flux for code contributions and the risk of you doing work in vain is very high.
